Caboodle
--------

A Python module for web browsing, web scraping or web automation

> [kuh-bood-l] **noun**, *Informal*
>
> 1. the lot, pack, or crowd

Install
-------

	pip install caboodle==1.0.0a3

Example
-------

	#!/usr/bin/env python
	from caboodle import web
	import time

	# Create the browser
	browser = web.Browser()
	browser.get('https://pypi.python.org')

	# Search for caboodle
	browser.find_element_by_id('term').send_keys('caboodle')
	browser.find_element_by_id('submit').click()

	# Wait and quit
	time.sleep(5)
	browser.quit()

License
-------

	Copyright (c) 2015, Justin Willis

	Permission to use, copy, modify, and/or distribute this software for any
	purpose with or without fee is hereby granted, provided that the above
	copyright notice and this permission notice appear in all copies.

	THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
	WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
	MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
	ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
	WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
	ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
	OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
